@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: image.py 615 2005-02-27 01:41:45Z pronovic $
+# Revision : $Id: image.py 752 2005-04-22 15:23:54Z pronovic $
 # Purpose  : Provides ISO image-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -156,7 +156,7 @@ class IsoImage(object):
       @type device: Either be a filesystem path or a SCSI address
 
       @param boundaries: Session boundaries as required by C{mkisofs}
-      @type boundaries: Tuple C{(last_sess_start,next_sess_start)} as returned from C{cdrecord -msinfo}
+      @type boundaries: Tuple C{(last_sess_start,next_sess_start)} as returned from C{cdrecord -msinfo}, or C{None}
 
       @param graftPoint: Default graft point for this page.
       @type graftPoint: String representing a graft point path (see L{addEntry}).
