@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 733 2005-03-23 19:38:47Z pronovic $
+# Revision : $Id: release.py 753 2005-04-22 15:24:11Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2005"
-VERSION     = "2.3.1"
-DATE        = "23 Mar 2005"
+VERSION     = "2.4.1"
+DATE        = "22 Apr 2005"
 URL         = "http://cedar-solutions.com/software/cedar-backup"
 
