@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: writer.py 685 2005-03-08 19:19:49Z pronovic $
+# Revision : $Id: writer.py 752 2005-04-22 15:23:54Z pronovic $
 # Purpose  : Provides image writer-related objects.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -618,7 +618,7 @@ class CdWriter(object):
          if result != 0:
             raise IOError("Error (%d) executing cdrecord command to get capacity." % result)
          boundaries = CdWriter._parseBoundariesOutput(output)
-         logger.debug("Returning disc boundaries (%d, %d)." % (boundaries[0], boundaries[1]))
+         logger.debug("Returning disc boundaries:", boundaries)
          return boundaries
 
    def _calculateCapacity(media, boundaries):
